@@ -226,7 +226,11 @@ class GoferHandler(HubOAuthenticated, tornado.web.RequestHandler):
         """
         self.write("This is a post only page. You probably shouldn't be here!")
 
+    @authenticated
     def get(self):
+        user_model = self.get_current_user()
+        self.set_header('content-type', 'application/json')
+        self.write(json.dumps(user_model, indent=1, sort_keys=True))
         self.write("This is a post only page. You probably shouldn't be here!")
         self.finish()
 
